@@ -302,7 +302,7 @@ void ContentTest::testEncodedContent()
         "body\n";
     msg->setContent(data);
     QByteArray content = msg->encodedContent(true /* use CRLF */);
-    QStringList lines = QString::fromLatin1(content).split(QLatin1String("\r\n"));
+    QStringList lines = QString::fromLatin1(content).split(QStringLiteral("\r\n"));
     foreach (const QString &line, lines) {
         QEXPECT_FAIL("", "KMime does not fold lines longer than 998 characters", Continue);
         QVERIFY(line.length() < 998 && !line.isEmpty() && line != QLatin1String("body"));
@@ -501,7 +501,7 @@ void ContentTest::testParsingUuencoded()
         "\n"
         "\n";
 
-    const QString imageName = QLatin1String("Name of the encoded file (oxygen 22x22 kde.png)");
+    const QString imageName = QStringLiteral("Name of the encoded file (oxygen 22x22 kde.png)");
     const QByteArray imageBase64 =
         "\n"
         "iVBORw0KGgoAAAANSUhEUgAAABYAAAAWCAYAAADEtGw7AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\n"
